Running the tools on Microsoft Windows — Translate Toolkit 2.5.0 documentation

# Running the tools on Microsoft Windows

Since the toolkit is written in Python, it should work perfectly on Windows.

## Add the toolkit to your path

### Windows 95/98

You might need to add the installation directory of the translate toolkit to your path

    path "C:\Program Files\translate-toolkit\"

This will work for one session, but will be lost when you reboot again. Therefore you might want to add it to the autoexec.bat file.

### Windows 2000/XP

You can add to the path permanently. Check this useful guide. You should add the following to your path:

    C:\Programs Files\translate-toolkit\

If you have the Gettext tools installed, add it to your path as well:

    C:\Program Files\GnuWin32\bin\

## Change Windows file to Unix file

Some programs in Windows will add CRLFs to the file which is considered rather poor practice for l10ns that require Unix files. To fix a text file, drag and drop it to the dos2unix.exe utility from http://www.bastet.com/